==> thunderbird_66.0~b1.orig.tar.xz: thunderbird-66.0/browser/components/newtab/prerendered/locales/cs/activity-stream-strings.js <==
// Note - this is a generated cs file.
window.gActivityStreamStrings = {
  "newtab_page_title": "Nový panel",
  "header_top_sites": "Top stránky",
  "header_highlights": "Vybrané",
  "header_recommended_by": "Doporučení ze služby {provider}",
  "context_menu_button_sr": "Otevřít kontextovou nabídku pro {title}",
  "section_context_menu_button_sr": "Otevřít kontextovou nabídku sekce",
  "type_label_visited": "Navštívené",
  "type_label_bookmarked": "V záložkách",
  "type_label_recommended": "Populární",
  "type_label_pocket": "Uloženo do služby Pocket",
  "type_label_downloaded": "Staženo",
  "menu_action_bookmark": "Přidat do záložek",
  "menu_action_remove_bookmark": "Odebrat záložku",
  "menu_action_open_new_window": "Otevřít v novém okně",
  "menu_action_open_private_window": "Otevřít v novém anonymním okně",
  "menu_action_dismiss": "Skrýt",
  "menu_action_delete": "Smazat z historie",
  "menu_action_pin": "Připnout",
  "menu_action_unpin": "Odepnout",
  "confirm_history_delete_p1": "Opravdu chcete smazat všechny výskyty této stránky z vaší historie?",
  "confirm_history_delete_notice_p2": "Tuto akci nelze vzít zpět.",
  "menu_action_save_to_pocket": "Uložit do služby Pocket",
  "menu_action_delete_pocket": "Smazat ze služby Pocket",
  "menu_action_archive_pocket": "Archivovat do služby Pocket",
  "menu_action_show_file_mac_os": "Zobrazit ve Finderu",
  "menu_action_show_file_windows": "Otevřít složku",
  "menu_action_show_file_linux": "Otevřít složku",
  "menu_action_show_file_default": "Ukázat soubor",
  "menu_action_open_file": "Otevřít soubor",
  "menu_action_copy_download_link": "Kopírovat stahovaný odkaz",
  "menu_action_go_to_download_page": "Přejít na stránku stahování",
  "menu_action_remove_download": "Odstranit z historie",
  "search_button": "Vyhledat",
  "search_header": "Vyhledat pomocí {search_engine_name}",
  "search_web_placeholder": "Vyhledat na webu",
  "section_disclaimer_topstories": "Nejzajímavější články na webu vybrané podle toho, co sami čtete. To je služba Pocket od Mozilly.",
  "section_disclaimer_topstories_linktext": "Zjistit, jak to funguje.",
  "section_disclaimer_topstories_buttontext": "Ok, rozumím",
  "prefs_home_header": "Obsah domovské stránky Firefoxu",
  "prefs_home_description": "Vyberte obsah, který chcete mít na výchozí domovské stránce Firefoxu.",
  "prefs_content_discovery_header": "Domovská stránka Firefoxu",
  "prefs_content_discovery_description": "Doporučování obsahu na domovské stránce obsahu vám nabídne kvalitní a relevantní články z celého internetu.",
  "prefs_content_discovery_button": "Vypnout doporučování obsahu",
  "prefs_section_rows_option": "{num} řádek;{num} řádky;{num} řádků",
  "prefs_search_header": "Vyhledávání na webu",
  "prefs_topsites_description": "Nejnavštěvovanější stránky",
  "prefs_topstories_description2": "Skvělý obsah z celého webu, vybraný speciálně pro vás",
  "prefs_topstories_options_sponsored_label": "Sponzorované články",
  "prefs_topstories_sponsored_learn_more": "Zjistit více",
  "prefs_highlights_description": "Výběr z uložených nebo navštívených stránek",
  "prefs_highlights_options_visited_label": "Navštívené stránky",
  "prefs_highlights_options_download_label": "Nedávná stahování",
  "prefs_highlights_options_pocket_label": "Stránky uložené do služby Pocket",
  "prefs_snippets_description": "Informace od Mozilly a o Firefoxu",
  "settings_pane_button_label": "Přizpůsobení stránky nového panelu",
  "settings_pane_topsites_header": "Top stránky",
  "settings_pane_highlights_header": "Vybrané",
  "settings_pane_highlights_options_bookmarks": "Záložky",
  "settings_pane_snippets_header": "Útržky",
  "edit_topsites_button_text": "Upravit",
  "edit_topsites_edit_button": "Upravit tuto stránku",
  "topsites_form_add_header": "Nová top stránka",
  "topsites_form_edit_header": "Upravit top stránku",
  "topsites_form_title_label": "Název stránky",
  "topsites_form_title_placeholder": "Zadejte název",
  "topsites_form_url_label": "URL",
  "topsites_form_image_url_label": "URL adresa vlastního obrázku",
  "topsites_form_url_placeholder": "Zadejte nebo vložte URL adresu",
  "topsites_form_use_image_link": "Použít vlastní obrázek…",
  "topsites_form_preview_button": "Náhled",
  "topsites_form_add_button": "Přidat",
  "topsites_form_save_button": "Uložit",
  "topsites_form_cancel_button": "Zrušit",
  "topsites_form_url_validation": "Je vyžadována platná URL",
  "topsites_form_image_validation": "Obrázek se nepodařilo načíst. Zkuste jinou URL adresu.",
  "pocket_read_more": "Populární témata:",
  "pocket_read_even_more": "Zobrazit více článků",
  "pocket_more_reccommendations": "Další doporučení",
  "pocket_how_it_works": "Jak to funguje",
  "pocket_cta_button": "Získejte Pocket",
  "pocket_cta_text": "Ukládejte si články do služby Pocket a užívejte si skvělé čtení.",
  "highlights_empty_state": "Začněte prohlížet a my vám zde ukážeme některé skvělé články, videa a další stránky, které jste nedávno viděli nebo uložili do záložek.",
  "topstories_empty_state": "Už jste všechno přečetli. Další články ze služby {provider} tu najdete zase později. Ale pokud se nemůžete dočkat, vyberte své oblíbené téma a podívejte se na další velké články z celého webu.",
  "manual_migration_explanation2": "Vyzkoušejte Firefox se záložkami, historií a hesly z jiného vašeho prohlížeče.",
  "manual_migration_cancel_button": "Ne, děkuji",
  "manual_migration_import_button": "Importovat nyní",
  "error_fallback_default_info": "Jejda, při načítání tohoto obsahu se něco pokazilo.",
  "error_fallback_default_refresh_suggestion": "Obnovte prosím stránku a zkuste to znovu.",
  "section_menu_action_remove_section": "Odebrat sekci",
  "section_menu_action_collapse_section": "Sbalit sekci",
  "section_menu_action_expand_section": "Rozbalit sekci",
  "section_menu_action_manage_section": "Nastavení sekce",
  "section_menu_action_manage_webext": "Správa rozšíření",
  "section_menu_action_add_topsite": "Přidat mezi top stránky",
  "section_menu_action_add_search_engine": "Přidat vyhledávač",
  "section_menu_action_move_up": "Posunout nahoru",
  "section_menu_action_move_down": "Posunout dolů",
  "section_menu_action_privacy_notice": "Zásady ochrany osobních údajů",
  "firstrun_title": "Vezměte si Firefox s sebou",
  "firstrun_content": "Mějte své záložky, historii i uložená hesla s sebou na všech svých zařízeních.",
  "firstrun_learn_more_link": "Zjistěte více o účtech Firefoxu",
  "firstrun_form_header": "Zadejte svoji e-mailovou adresu",
  "firstrun_form_sub_header": "a používejte službu Firefox Sync.",
  "firstrun_email_input_placeholder": "E-mail",
  "firstrun_invalid_input": "Je požadován platný e-mail",
  "firstrun_extra_legal_links": "Pokračováním souhlasíte s {terms} a {privacy}.",
  "firstrun_terms_of_service": "Podmínkami používání služby",
  "firstrun_privacy_notice": "Zásadami ochrany osobních údajů",
  "firstrun_continue_to_login": "Pokračovat",
  "firstrun_skip_login": "Přeskočit tento krok",
  "context_menu_title": "Otevře nabídku"
};

==> thunderbird_68.10.0.orig.tar.xz: thunderbird-68.10.0/browser/components/newtab/prerendered/locales/cs/activity-stream-strings.js <==
// Note - this is a generated cs file.
window.gActivityStreamStrings = {
  "newtab_page_title": "Nový panel",
  "header_top_sites": "Top stránky",
  "header_highlights": "Vybrané",
  "header_recommended_by": "Doporučení ze služby {provider}",
  "context_menu_button_sr": "Otevřít kontextovou nabídku pro {title}",
  "section_context_menu_button_sr": "Otevřít kontextovou nabídku sekce",
  "type_label_visited": "Navštívené",
  "type_label_bookmarked": "V záložkách",
  "type_label_recommended": "Populární",
  "type_label_pocket": "Uloženo do služby Pocket",
  "type_label_downloaded": "Staženo",
  "menu_action_bookmark": "Přidat do záložek",
  "menu_action_remove_bookmark": "Odebrat záložku",
  "menu_action_open_new_window": "Otevřít v novém okně",
  "menu_action_open_private_window": "Otevřít v novém anonymním okně",
  "menu_action_dismiss": "Skrýt",
  "menu_action_delete": "Smazat z historie",
  "menu_action_pin": "Připnout",
  "menu_action_unpin": "Odepnout",
  "confirm_history_delete_p1": "Opravdu chcete smazat všechny výskyty této stránky z vaší historie?",
  "confirm_history_delete_notice_p2": "Tuto akci nelze vzít zpět.",
  "menu_action_save_to_pocket": "Uložit do služby Pocket",
  "menu_action_delete_pocket": "Smazat ze služby Pocket",
  "menu_action_archive_pocket": "Archivovat do služby Pocket",
  "menu_action_show_file_mac_os": "Zobrazit ve Finderu",
  "menu_action_show_file_windows": "Otevřít složku",
  "menu_action_show_file_linux": "Otevřít složku",
  "menu_action_show_file_default": "Ukázat soubor",
  "menu_action_open_file": "Otevřít soubor",
  "menu_action_copy_download_link": "Kopírovat stahovaný odkaz",
  "menu_action_go_to_download_page": "Přejít na stránku stahování",
  "menu_action_remove_download": "Odstranit z historie",
  "search_button": "Vyhledat",
  "search_header": "Vyhledat pomocí {search_engine_name}",
  "search_web_placeholder": "Vyhledat na webu",
  "section_disclaimer_topstories": "Nejzajímavější články na webu vybrané podle toho, co sami čtete. To je služba Pocket od Mozilly.",
  "section_disclaimer_topstories_linktext": "Zjistit, jak to funguje.",
  "section_disclaimer_topstories_buttontext": "Ok, rozumím",
  "prefs_home_header": "Obsah domovské stránky Firefoxu",
  "prefs_home_description": "Vyberte obsah, který chcete mít na výchozí domovské stránce Firefoxu.",
  "prefs_content_discovery_description": "Doporučování obsahu na domovské stránce obsahu vám nabídne kvalitní a relevantní články z celého internetu.",
  "prefs_section_rows_option": "{num} řádek;{num} řádky;{num} řádků",
  "prefs_search_header": "Vyhledávání na webu",
  "prefs_topsites_description": "Nejnavštěvovanější stránky",
  "prefs_topstories_description2": "Skvělý obsah z celého webu, vybraný speciálně pro vás",
  "prefs_topstories_options_sponsored_label": "Sponzorované články",
  "prefs_topstories_sponsored_learn_more": "Zjistit více",
  "prefs_highlights_description": "Výběr z uložených nebo navštívených stránek",
  "prefs_highlights_options_visited_label": "Navštívené stránky",
  "prefs_highlights_options_download_label": "Nedávná stahování",
  "prefs_highlights_options_pocket_label": "Stránky uložené do služby Pocket",
  "prefs_snippets_description": "Aktuální informace od Mozilly a Firefoxu",
  "settings_pane_button_label": "Přizpůsobení stránky nového panelu",
  "settings_pane_topsites_header": "Top stránky",
  "settings_pane_highlights_header": "Vybrané",
  "settings_pane_highlights_options_bookmarks": "Záložky",
  "settings_pane_snippets_header": "Útržky",
  "edit_topsites_button_text": "Upravit",
  "edit_topsites_edit_button": "Upravit tuto stránku",
  "topsites_form_add_header": "Nová top stránka",
  "topsites_form_edit_header": "Upravit top stránku",
  "topsites_form_title_label": "Název stránky",
  "topsites_form_title_placeholder": "Zadejte název",
  "topsites_form_url_label": "URL",
  "topsites_form_image_url_label": "URL adresa vlastního obrázku",
  "topsites_form_url_placeholder": "Zadejte nebo vložte URL adresu",
  "topsites_form_use_image_link": "Použít vlastní obrázek…",
  "topsites_form_preview_button": "Náhled",
  "topsites_form_add_button": "Přidat",
  "topsites_form_save_button": "Uložit",
  "topsites_form_cancel_button": "Zrušit",
  "topsites_form_url_validation": "Je vyžadována platná URL",
  "topsites_form_image_validation": "Obrázek se nepodařilo načíst. Zkuste jinou URL adresu.",
  "pocket_read_more": "Populární témata:",
  "pocket_read_even_more": "Zobrazit více článků",
  "pocket_more_reccommendations": "Další doporučení",
  "pocket_how_it_works": "Jak to funguje",
  "pocket_cta_button": "Získejte Pocket",
  "pocket_cta_text": "Ukládejte si články do služby Pocket a užívejte si skvělé čtení.",
  "highlights_empty_state": "Začněte prohlížet a my vám zde ukážeme některé skvělé články, videa a další stránky, které jste nedávno viděli nebo uložili do záložek.",
  "topstories_empty_state": "Už jste všechno přečetli. Další články ze služby {provider} tu najdete zase později. Ale pokud se nemůžete dočkat, vyberte své oblíbené téma a podívejte se na další velké články z celého webu.",
  "error_fallback_default_info": "Jejda, při načítání tohoto obsahu se něco pokazilo.",
  "error_fallback_default_refresh_suggestion": "Obnovte prosím stránku a zkuste to znovu.",
  "section_menu_action_remove_section": "Odebrat sekci",
  "section_menu_action_collapse_section": "Sbalit sekci",
  "section_menu_action_expand_section": "Rozbalit sekci",
  "section_menu_action_manage_section": "Nastavení sekce",
  "section_menu_action_manage_webext": "Správa rozšíření",
  "section_menu_action_add_topsite": "Přidat mezi top stránky",
  "section_menu_action_add_search_engine": "Přidat vyhledávač",
  "section_menu_action_move_up": "Posunout nahoru",
  "section_menu_action_move_down": "Posunout dolů",
  "section_menu_action_privacy_notice": "Zásady ochrany osobních údajů",
  "firstrun_title": "Vezměte si Firefox s sebou",
  "firstrun_content": "Mějte své záložky, historii i uložená hesla s sebou na všech svých zařízeních.",
  "firstrun_learn_more_link": "Zjistit více o účtech Firefoxu",
  "firstrun_form_header": "Zadejte svoji e-mailovou adresu",
  "firstrun_form_sub_header": "a používejte službu Firefox Sync.",
  "firstrun_email_input_placeholder": "E-mail",
  "firstrun_invalid_input": "Je požadován platný e-mail",
  "firstrun_extra_legal_links": "Pokračováním souhlasíte s {terms} a {privacy}.",
  "firstrun_terms_of_service": "Podmínkami používání služby",
  "firstrun_privacy_notice": "Zásadami ochrany osobních údajů",
  "firstrun_continue_to_login": "Pokračovat",
  "firstrun_skip_login": "Přeskočit tento krok",
  "context_menu_title": "Otevře nabídku"
};
